summaryrefslogtreecommitdiffstats
path: root/contrib/gcc/config/frv/frvbegin.c
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/gcc/config/frv/frvbegin.c')
-rw-r--r--contrib/gcc/config/frv/frvbegin.c33
1 files changed, 20 insertions, 13 deletions
diff --git a/contrib/gcc/config/frv/frvbegin.c b/contrib/gcc/config/frv/frvbegin.c
index a5f5b1f..d021b35 100644
--- a/contrib/gcc/config/frv/frvbegin.c
+++ b/contrib/gcc/config/frv/frvbegin.c
@@ -1,26 +1,33 @@
/* Frv initialization file linked before all user modules
- Copyright (C) 1999, 2000 Free Software Foundation, Inc.
+ Copyright (C) 1999, 2000, 2003, 2004 Free Software Foundation, Inc.
Contributed by Red Hat, Inc.
- This file is part of GNU CC.
+ This file is part of GCC.
- GNU CC is free software ; you can redistribute it and/or modify
+ GCC is free software ; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation * either version 2, or (at your option)
any later version.
- GNU CC is distributed in the hope that it will be useful,
+ GCC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY ; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with GNU CC; see the file COPYING. If not, write to
+ along with GCC; see the file COPYING. If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
This file was originally taken from the file crtstuff.c in the
- main compiler directory, and simplified. */
+ main compiler directory, and simplified. */
+
+/* As a special exception, if you link this library with other files,
+ some of which are compiled with GCC, to produce an executable,
+ this library does not by itself cause the resulting executable
+ to be covered by the GNU General Public License.
+ This exception does not however invalidate any other reasons why
+ the executable file might be covered by the GNU General Public License. */
#include "defaults.h"
#include <stddef.h>
@@ -74,7 +81,7 @@ extern void __frv_deregister_eh(void) __attribute__((__destructor__));
extern func_ptr __EH_FRAME_BEGIN__[];
/* Register the exeception handling table as the first constructor */
void
__frv_register_eh (void)
{
@@ -86,7 +93,7 @@ __frv_register_eh (void)
/* Note, do not declare __{,de}register_frame_info weak as it seems
to interfere with the pic support. */
/* Unregister the exeception handling table as a deconstructor */
void
__frv_deregister_eh (void)
{
@@ -101,9 +108,9 @@ __frv_deregister_eh (void)
completed = 1;
}
-/* Run the global destructors */
+/* Run the global destructors. */
void
-__do_global_dtors ()
+__do_global_dtors (void)
{
static func_ptr *p = __DTOR_LIST__ + 1;
while (*p)
@@ -113,9 +120,9 @@ __do_global_dtors ()
}
}
-/* Run the global constructors */
+/* Run the global constructors. */
void
-__do_global_ctors ()
+__do_global_ctors (void)
{
unsigned long nptrs = (unsigned long) __CTOR_LIST__[0];
unsigned i;
@@ -138,7 +145,7 @@ __do_global_ctors ()
to run __do_global_ctors, so we need not do anything here. */
void
-__main ()
+__main (void)
{
/* Support recursive calls to `main': run initializers just once. */
static int initialized;
@@ -74,7 +81,7 @@ extern void __frv_deregister_eh(void) __attribute__((__destructor__));
extern func_ptr __EH_FRAME_BEGIN__[];
-/* Register the exeception handling table as the first constructor */
+/* Register the exception handling table as the first constructor. */
void
__frv_register_eh (void)
@@ -86,7 +93,7 @@ __frv_register_eh (void)
/* Note, do not declare __{,de}register_frame_info weak as it seems
to interfere with the pic support. */
-/* Unregister the exeception handling table as a deconstructor */
+/* Unregister the exception handling table as a deconstructor. */
void
__frv_deregister_eh (void)
OpenPOWER on IntegriCloud